@@ -295,26 +295,6 @@ class DicomReaderWriter:
         elif self.get_images_mask:
             self.use_template()
 
-    def add_RT(self, PathDicom):
-        RT_Files = [os.path.join(PathDicom, i) for i in os.listdir(PathDicom) if i.find('.dcm') != -1]
-        reader = sitk.ImageFileReader()
-        for lstRSFile in RT_Files:
-            reader.SetFileName(lstRSFile)
-            try:
-                reader.ReadImageInformation()
-                modality = reader.GetMetaData("0008|0060")
-            except:
-                modality = pydicom.read_file(lstRSFile).Modality
-            if modality.lower().find('dose') != -1:
-                self.RDs_in_case[lstRSFile] = []
-            elif modality.lower().find('struct') != -1:
-                self.RTs_in_case[lstRSFile] = []
-        self.all_RTs.update(self.RTs_in_case)
-        if len(self.RTs_in_case.keys()) > 0:
-            self.template = False
-            for self.lstRSFile in self.RTs_in_case:
-                self.get_rois_from_RT()
-
     def write_parallel(self, out_path, excel_file, thread_count=int(cpu_count()*0.9-1)):
         out_path = os.path.join(out_path,self.desciption)
         if not os.path.exists(out_path):
@@ -442,11 +422,7 @@ class DicomReaderWriter:
             self.row_val = matrix_points[:, 1]
             z_vals = matrix_points[:, 2]
             temp_mask = poly2mask(self.row_val, self.col_val, [self.image_size_rows, self.image_size_cols])
-            mask_indexes = np.where((self.row_val > 0) & (self.row_val < self.image_size_rows) &
-                                    (self.col_val > 0) & (self.col_val < self.image_size_cols))[0]
-            mask_rows = self.row_val[mask_indexes]
-            mask_cols = self.col_val[mask_indexes]
-            temp_mask[mask_rows, mask_cols] = 0
+            temp_mask[self.row_val, self.col_val] = 0
             mask[z_vals[0], temp_mask] += 1
         mask = mask % 2
         return mask
